@@ -110,7 +110,7 @@ class SDHProcessor(Processor):
     def contains_hi(line: Line) -> bool:
         return bool(
             re.search(
-                r"^([-\s<i>]+)?((\b[-\w.']+\s?#?\d?){1,2}(?!\.)([\[(][\w\s]*[\])])?:(?![\S])|[\[]+.*[\]:]+)(\s+)?|\s?[(\[*].*?[)\]*:]+\s?",
+                r"^([-‐\s<i>]+)?((\b[-\w.']+\s?#?\d?){1,2}(?!\.)([\[(][\w\s]*[\])])?:(?![\S])|[\[]+.*[\]:]+)(\s+)?|\s?[(\[*].*?[)\]*:]+\s?",
                 line,
             )
         )
@@ -119,7 +119,7 @@ class SDHProcessor(Processor):
     def clean_hi(cls, line: Line) -> Line:
         """Clean hearing impaired."""
         line = line.sub(
-            r"^([-\s<i>]+)?((\b[-\w.']+\s?#?\d?){1,2}(?!\.)([\[(][\w\s]*[\])])?:(?![\S])|[\[]+.*[\]:]+)(\s+)?",
+            r"^([-‐\s<i>]+)?((\b[-\w.']+\s?#?\d?){1,2}(?!\.)([\[(][\w\s]*[\])])?:(?![\S])|[\[]+.*[\]:]+)(\s+)?",
             r"\1",
         )
         line = cls.clean_parentheses(line)
@@ -220,6 +220,7 @@ class ErrorProcessor(Processor):
     def __init__(self, subtitle: Subtitle, *args, **kwargs):
         super().__init__(subtitle, *args, **kwargs)
         self.operations: list[Callable] = [
+            self.fix_styles,
             self.fix_hyphen,
             self.fix_spaces,
             self.fix_space_punctuation,
@@ -229,6 +230,11 @@ class ErrorProcessor(Processor):
             self.fix_music,
         ]
 
+    @staticmethod
+    def fix_styles(line: Line) -> Line:
+        """Remove leftover style tags"""
+        return line.sub(r"<i>(\s*)<\/i>", r"\1")
+
     @staticmethod
     def fix_spaces(line: Line) -> Line:
         """Add missing spaces between sentences."""
